use strict;
use GD;

my $outfile = 'c:/download/capture.jpg';
my $pixheight = 1;
my $pixwidth = 3.75;
my $gamma = 1.5;

my @pixels;

while (<DATA>) {
	chomp;
	push @pixels, [map {ord($_) - 64} (split(//, $_))]
}

my $height = @pixels;
my $width = @{$pixels[0]};
my $maxpix = 0;
my $minpix = 255;

foreach my $y (0 .. $height - 1) {
	foreach my $x (0 .. $width - 1) {
		my $pix = $pixels[$y][$x];
   	$maxpix = $pix if $pix > $maxpix;
   	$minpix = $pix if $pix < $minpix;
	}
}

print "$width $height $minpix $maxpix\n";

my $image = GD::Image->new($width * $pixwidth, $height * $pixheight, 1);

foreach my $y (0 .. $height - 1) {
	foreach my $x (0 .. $width - 1) {
		my $pix = int((($pixels[$y][$x] - $minpix) / ($maxpix - $minpix)) ** $gamma * 255) * 0x010101;
		$image->filledRectangle($x * $pixwidth, $y * $pixheight, $x * $pixwidth + $pixwidth - 1, $y * $pixheight + $pixheight - 1, $pix)
	}
}

my $jpg = $image->jpeg;
open JPG, ">$outfile" or die;
binmode JPG;
print JPG $jpg;
close JPG

__END__
\ddeeffffgfghhhhhiiiiijjhjijiiiiiihiihihihhhhigghiijkmmmmmmmgdgfig^mmmmmmmmmmllkjihffeeddcc
[cdddeeeffgfggghhhhhhihiiiiihihhighhhghhghhghgggghikmmmmgemmhcffhi]jmmmmmmmmmlkkihgfeddddcb
Zccccdedeeefffggggghggighighghghghggggggggggffgfhhjlmmmg\dmmibeehi_elmmllmlllkkjihfeddccbca
Ybbbccdceedfeeffggfgghghghgggghfggfffgfffffgegffhilmmmh[\dmmj_dehhd`kllmlllklkkihgeedccbbba
Xcabbcbcceceedefffffffgfhfgfgfgffffeeeefefefefehgjmmmg[\\blmk]ddhgf[kklkklkkkkiigfeecbbaca`
Xabcaabbdcdcdeedegfffegfffffffgeefeeedeeedfeeffhjllmh\[[\blll]cdghg\hkkkkkkkkjjhgfdcdcbaaa`
W^babaabcbbcddddeeeeefffffefeeeededddedddddefegijllg\ZZ\[aklm^aefgg`bkkkkkkjijihfeecbaaaa``
VW^abbbabcbdbdddedeedeffeefdfdfddddddcdcdddeeghjili[Z[[ZZ`klm__eeggb_jkkkkjkjihhfedcbc``a`_
UXX]`ab`baabccccdeddeeeeeedddeddcdccdbdccceefhkkkiZZZ[YZZ`kklb[eegfe]jjjkjjiiihgfedbbaa```^
VYXX]aababacbcccddddedededeedddcdcccbccbcddggjlki\YZ[[ZZY_kklfYeefgf[ijkjjijihhgfdcca`a`_`^
V]XXV\`ac`aacbccbdcdecdedcecddbccccbabcbbddgjkki\YZZ[^ZZY^kkkf\aeffgZhijjjjihhhfeecba`_`___
U^]XXWZ_abbabbcccccdddedddceccccbbcbbbbccefikkj\YZY[]]YZZ]kkjga^eeff\fijjiiihhhgeddaa`____^
TZ]YXWWY_bbababbbdcccdddcdcdcccbbbabaacccfhkkj]XYZZ]^YZYY]jkifeYeeff]eiiiiihhhgfedbb``___^^
TWZY^YWWX^ad`bbbbbccccdcdddccbbbbaabaabbfgkkjaW[YY]^YYYYc\jkghgYcfff]diijiihhhggedca``__^^^
SWVX]^XWWX_`baabccbcbcddcdcccabbaaaabacdfjkk`W[]Y[^YXYZeh[jjfig\_efe_ahiiihighfgddca`___^^^
SVWVX]YXWVW_acacacbcdccccdccbcbaaa`aabdfikjaWY\[\_ZYYZdkgZjjfiga[eef``hiiigihggfedc````^^^^
RWWWVWXWWWWW]acbabbbdccccdbccaaa`aa`bbeijjgZY^[X_\YZYbjgdZijdhgcYcef`_hihihhgggfecb``_^_^]_
SVVVVVWVXXWWU]`bcbbbcdbcdcccbbaa```abdhjjdYY][Y\[]\X`jiffYikeifd\`efa^hiihhhgggfddba`__^_^^
RVWUVWVVVWXWVW[aabcbbccbdccbba````aadfijfXW[]Z\[\bZ^hifZ^Xiidhfe^\dfc\giihgghgefdca``__^_]^
RWVVVWVVVWWVXVWZabcbbccccdccbaa`aaacfjjeYX]\X^][b\]gfg_\aYhjehfebYdfb[hhhhhgggffdcba``___^^
RVVVVVVVVWWVWWVVZ`bcbbcbccccaa`a_`cdhigYXZ]Y[]Yb\\fddf\acXhjdheeeYaed[ghhhghfffeccba`a`__]_
RVVVWVVVVWVWWXVWVZ`ccbcccdbbca``abdhjhZW[\Y\^[Z^[agbad_ahWhjegfdd^[eeYghhhhgggeedcbbaa`__]^
QUWUVVUWVVVWVWWWVUY`bbcccccbba``bcgjh]U[]Y[^Z^]Z`ed[Yc`bjWgidgeedbWcdZfhhhgggffedcbbb``_`^]
RQVVVVVVVVVVWVWVWXUY`bcdccbcbaabbfjh_VZ\XZ\[\b[^cc_Z_e^biXghfgeeddY_eYfhhhhggfedddccab_``^^
UaQWVUVWVVWVVWWVWVWUX_ccbccbcbabehiaVWYVY]Z\_[]c`b]^bihdeWggggeedd]XeYfghghggeeeddbbca`a^_^
UjdSUVVVVWVVVWVVWWWWUW_bccbcbbccihdUXWWZ][[b\[ba]_\`fhjgeXffggeedd`WbYehhghgfefedccdaba`_^^
UeifVSWVVWVVVVVVWWVWVVW_adccbbcgjeVWXXY][Z\^Zba^Y_^_ghgfeXfehgeeddb[ZYeggggfgeeeecccbb``__^
UfdjjWSVWVWVVVVWVWUWWWXZ]bccccgifXWVX\^Z[bYZ_baZ[bfagefdfXfdigeeddb_XYeghgffgfdeddcbcb``^^^
UhgdjkZRVWVWVVWVVVVVWW]_Z]bbdbfgZUWWY[[Yb]X`a``[_cggfgeafWfdhgeedcbaZYdggfgfefeedcccbaa`_`^
Sdjgfhk^SWVVVWVUWVVVVW^jbZ]aaY[^UWWZ[X[b\Y_b_a^\`dgghfddgXedhgeeddba^]dghgfgefeedccbcb``^__
S`hgifhkbRVVVWVUWVUWVV_gibZ][^]ZWWW]ZX`\Z]a_]aa]^dfiifafbYddhgeeddba``dgggegeeeeddbbbaa`_`_
SafdiiefmdTVVWUVVVUWUW`ggicZX_`^WYYZZb\Y]a__`_bc`diiifc`bXddhgfedcbb``dggfffeadeccdbbb````^
R`g_ahjeekgTTWUVVVUVUWaddgjcX[_\[\ZV`\WX`\\_``bddhihif^]cXdchffeddbaa`efffffd_cdcccbba``___
S]gcbghiffkiVTVVUWUUVWbfcdheW[_Z]XWV\XWY_[[^^addhihhhfa_eZbdggeeeccabbdfgffedXcdcccc`c`_``_
Tgg_cfcfjhejkXTUVVUVUVcgbcf_Xf_YZVWUWXZZ]Z_`^bcgihf]hfcceZ_fgffeddbbacefgefe`V\cdcbbbb`_a^_
Sbh`^gc`hiifjl\RUVVVUVchbdg[YifYWXUXYX\[[\`badhiif_Xhfeee[^fhgfeeccbcdffffef\WW`dcbbbab^``_
S__gbfecehhifil`QVVTUWcdTbfZY\]ZVXW]]Y]Y^a_bcgiih_Y[hfeeh\\ghfffedccdefffeefYWUXaccbaa`_`__
Rbacii_deedijgimcRTVUWecS_fYWTUZVY\^[Z[Z`dabgiihh_\\hgeeg]\hgggffeeeeeffgeebYWWU\cbbab`_``_
Q_bbche]dfafjhghlfQTUWeeU\eYXcbWZZ\\[XYZ`aaeihhhhca^gefdh\\ggggffeeeeffffef^WWWTU_bba`a___^
Q_`_cegggeeehhkhhlhVRXegX[eVYgdZW]Z^ZYZZ`ceihihhhebbggedg[^ggghgffeefegfefe[WWVSTXacaa`____
P_`^aggfibaef_hjigkjXTff_^cUYhb_[WZ^[YZ[`eihigghgfcehge`h\^gggggffefgffefedWXVTSRT\`aa___`_
Qa`]`dfibfbdgdbjjhckl_gfgfdUXea]aWY_[Y]Zehhhhghgggfghh]ed[_ggggggffffffffebVXVRSSRU^aa`_`_`
Rc]\_d[chchhedehcjjgilfgfddUW^_^b[W`Z[[bhhhhgfacabggggbfd_]gggggfffgefffef\WWVSQSRUW``^`__`
R`c]_c__highg_di_gkigjgc_daTW\\`_^V]Z[chhghhg`[_`_dghfddg_]fggggggffgfffeeYXWSRTRRWU^a]`_``
Q\`cca^_f`ihghdggdihkjd]Sd`TXZZ\_^WZ[bhhgggfgb`^`]`gge``caZgfggggfgffeffebXVVRSSSQUU[_^_`__
R[^cedZ`f]`jhgjebdhaijeZUb`S\`[[^]X\dhhgggdfga\__[_hgga_baZggghggggfgeffe_VWVSRSSRUU]__`___
P\\_che^e`^gfjgia`hafjf]T_^T^e]Y^_Y^gggghbagg`__\[]hggd``aXgfgggggffffefe[WVUSSRSRSV^`^__`^
OZ\\^cgid\_h]cijkhhaejebUbZScg]X^`_^ggfhe_`fgaba]_Zgggc`d]YffggggggffgfeeUXVTSSRRTTWa`^``__
OXZ\\]bdh^]g^[ggjkg`dife\cYU^f]W_ddZecff^bbgfbeeca[ggfdccZYeggggfgfgefeeaSWVSSSRQTUZa__`___
OUWY\^^^bicg\^geijjhajeefe]SWf]W^eeW[`gb`^bed`[\af^gggebcZWfggggggffgfff[WUWRURRRTT]b]``^_`
OR[XY[^^^eigZ]h_bijkjifee``RW`\X^dfWXae[_`aaXVWWYc`ggfb_`ZWegggggggffffeYWVVUSSRRTV_a^`____
OSYVWY\]^_ehf\hf_gikkiggdbc^W^ZX_edW_d`a\``XVYYXY\`ggfd``ZWffghggfgfgffe^WWVVRRRSUW`a_`__`^
OQWUW[X[]^^cgihceg`fjhggecec]ZWZ\eeX`f\b\aWXYXXXXZcggeb`[[Wdgggggggffefe`YXVTSQRTUZ``^``___
NQTSWYVYZ^^^^eiaag`\ghhabedcb`ZY[eeYca[baYXXYXXYYYcggea[[YWegggggggfgffe_[VWUUTQUT^a`^``_`^
OTSRUWTUW[]^^`iidgb`fggYXbV^ad[[^fcYd]Y^\XXYXXXXZXdgge_Y^[WegggggfgffffebZXVWTVSTV`a_`_`_`_
OYVQTTUTVWZ]^^egjj^`fhgXXbS\ee[[^ed[`^`aWYWYYYXZYZdggf\_a\WegggggggggfefcZ[VWTVUUXaa^a``_`_
PUYYSSSUUUWY]^^^fjh^fgfc]cSYfd[Z^ed][`bZXXYYXXZZZ\dgge_cb]Ueggggggggfgeee`YXVVTVV[aa_a_`___
OUXW[TPUUUUWX]^_`ijjigeeddVZfe\Y_ee[_`aXXXXYYYZ\\`eggf_e__UfggghgggfggfffdZZWWTRU^bb_a``_`_
PWTYW\URTUUUVX\^^^cijfeaceZ[fd[Z_ff[_`\XXXYXYZ\^_afggf\]^`UdgggggggggfffedaWYVUTU`ab_a`_`_`
P_ZUXXZZSTTUVUXZ^_^cjgdbddddfd[]_egZ]aXYYXYY[[_`bbggggc__[Udgghghgggggffeed[XWVSWbaa`````__
OX^]UUZY\RSUUVUWZ^^_cgecddbehcYYYfeY\^YXYYYZ\_`bbegggfd`YUTdhggggggggfffeedaXXTR\baa`a_``__
PXX]_Y[ZY`TSUUUVVZ]^^`ffdbcdhbXVXffXd[XYZY[\__ccbegggfaYYYTdgghggggggggffedd]WUT^bb`aa``_`_
O_ZW[`[Z\``YRUTUVU[]__`ecccbhbWUZefWdYXXYY]^`ccaYeghgfWXZ]TcggghggggfgfefedeaYTUaab`b````__
OX]\YZ_]]``_[TSTUV^Z]]_aaefdhbVUZgdWaYXYZ\^abdcZ[dghgfY[^_Sdghggggggggffefdec][\abc`b`a`a__
NUY\_XY_a``]]\TRUV]U\Z^`_cffhaUUZfdW\YY[\]`ccd][achggf[\b_Sdghggggggggffeedecc`bbca`ba```_`
MQUXZ_[Y^`a]]]^VRVYT][\]``aeh`UU\faY^XZ\^_bcd_[acfgghfZ_f]Tbghgghgggggffefdecdcccbb`bb``a_`
NSRTXY_\Y\``[^]^XTTT\XY\^__ag`TU\f_ZZZ[]__dca]bddfgggg[`bYTbghggggggffffefedcdcbdbaaaa``_``
MOSSSXY^_YZ``^]^]]TRWVZ]Y\_`_]VW[f\^Z[\``adb_cefcggghf\]XVSbgghhgggggfffeeedddccccabaaa_```
O[RRRSWY]`YZ^a^Z^^]SUTYYX]\^_\TV\eXa\\^b`bb`decfggcggf[YXWTagghgggggfgffeeedddccbbac`b_```_
P_^SQTSUZaa]Z]b_[^^^WQWVX^W\^[RU\eWc`^ada`bcededgg_dggYYZWTagghhhgggfgffefededccccaaab`````
O^^^XPTTW`[__Y\ba]^^^YSUW[U_ZWST\eWda\ada`cdedgcgg^_ggYZXUT`gghggggfgfffefeeddcccbaaba`````
P^^^^[QRY`YZ]`\\`b^]^^]RUVT^WURT^aYf_YaaabeecgffheachgZWXTUagghhggggggfffeeddddcbcababa````
P^^^^^]TX`VUZ]`\[_b_]]^^WSTZUTRV]`[f[X^bc`ccfeegheachgZWX\Y`ghgggggfgffffeedddccbcaab`b```_
O_^^^^^^\aTTTY[__\^ba^^_^XSUTSRU^]_g_X[a\[\dfbfhgfafhgZV`e]agghhgggfgfffeefedddccabbaba``a`
P^^^^^^^^`SSTTV[_`[]aa___^\SQTRU`XaffZYXYZbhdegggf`fgh[bf_^aghghgggfgfgeefdeddcccabbb`a````
P^^^^^^^^_VURTTVZ^a\\`c_]^^^TQSW_Wdgfd^]_egggghggg`_hhahb^^aghhgggggffgfefeddddbdababa`a```
O_^^^^^^^^V^XQTSSZ\c^[_c`[^^aYRW^Ubcggfghfcdghfggdbcghbg[^_`ghggghfgegfffededdcdcaabbaa```_
O_^^_^^^_^W^^[RSSR[b__\]da^^ddbZ]V][dgigfdcgghfge]aghhcaY^_`gghggggfgffffeeddddcc`cabaa````
P]_^^^^]`\Y^^^]TQTSbZ]`\\bb`ccfYYVXWgihgeefggggg_\Zchfd\Y_]`gggggggfffffeeeddddcbbab``a```_
P]_^^_^]`[Z^^^^]WQVbS[]a_\_ddecUVWWWjijihiggghgf^^_ehfa[[`^`gggghfgfffffeeeeedccbbbbaa`a```
O[^^^^^]`ZZ^^^]^^YWaQRY]``[]cddVTYVYkiijihhhhifZ\\fhhe_]]b_`ggggggfgffefeededcdcabcbaa`````
O`\^]_^]`Y[^^^^^^^]aQRRW]_`^^adURZW[jjiiiiihhffUUZchic`cbda_gghgggggfffeefdedddd`cbaba`````
O`__[^^^`W[^^^^^^]]_RPRQU[^a_]dSSZV\ljiifghhgbcUSTYiicaabca`fhggggffgffefedddcdcbacaaaa````
O__a_\]^aW\^^^^^^^^^XWQQRSZ]bbdWTZ]`kjiicehgigcSSSTaicc\[gb_gggggggfgeffefdeedcdabbbaaaa```
O__```^Z`V]^^^^^^]^]Y^YQQQRYaec\U]gckjiid^ceghieVPRPZaf`dja^gggggggfffefefdedcdd`bbab``a``_
N`^a_aaaaT]^^^^^^^^[[]^\RPSSbcd\V_ebljiiiga_gggih^RRPU`ejia^ggghggggffffeeeddddcbbbaba`a```
O_U]`a``a[[^^^^]_]_Z[]\^\VOScdcZ\adbkjgehihchcfghjeWPRQYgga\gggggggffffeefedddcbabcba``a``_
O_R^```a`a`[^^^^^]_Y\^]^[]YRcdcV``cckjgccfhihecefhii]RQQSca\ggghggggffeeeedeedcaccaba`a````
M_^_```a``aa\]^^^]`Y\\^]\\\\cd`S`aacljedcbcgiggccdgiidUQQOW\fggggggfffeeeededdcabcbaa`ba_``
M\^a_`a```aab^\^^]aW]\^]\]\Zdd`R`a`cljedcbbcehihecdfhih\PQQUbghggggffffeeeedddcadbbaa`aa```
LWY^_````a`b`b_\]]`W]]]]\]\[dd`R]`XdkiedbcacacfihfcdgghibTPQQ]fgggfgfefeedeedcd`bcbbaa``a`_
MXVZ]_`a``aaaabc\[`W]]]^]][[ec`R]aYdlifcdbbbbacdhigeegggifZQQOT\eggffgeefdeedddadbabaaa`a``
N^YXX[]a_`aa`babb_aU]]]]]][\dc`R\c\djjeccabbaabbaghhfgggehi_PQQORffgffefededdccadbab``a````
M^[VXXZ]``a`a_abbcbYZ]]]]]\[de`R\c^clidc`]ababbabbchhgghgeghdXPSOdfgfffeedeedcdbcbbaaa`a```
M]]UTXYX]^a`aSaabbba^\\]]]\[dd_S[e^dlidc]UX_aaabaaaaeggggfcehf^RPaefffefeddedcccbbabb`a````
M]]XVXYXY\]`aUabbabbc`\]]]\[ec_P\d`clidc\RUW[`bbababacfhgga^cggUP^dfffefededddacccbb`ba`a``
N]]VXTYYYYY__babbaabbab][]]\cdYS[d_dkidc[QQTUV\bb`bab`adgfd]\gfVO[befffeeedddcaccbca`aa````
M]\WXUWVYXZY]`ababbbbbbc_]\\ddWT[e]dkidc[RRQQTTZ_aaabaaabffe^gfWOX_cffefefeddeadcbbabb`b```
M][WWXXUXWXYZY^aabbbbabbca]\dcVS[c\ekidcZRRRQPRSU\`aaaa``adfgff^QUZ_adefedeeddacccaaabaa`a_
N\ZTVUXYYUXX\YZ]`bbbbbbbcccaddWR[e[fkjdb[SSSQQQPRTW^aaaaaaaafgfccZUX[_cefeededbcdcbaabaa`a`
L\YQUVVTWXZ[a^YZ\_bbbba`cbdbceWQ[d\ekicc[SSRRRQPOQRVZ``a`aaaacgaee^UTY\aceedecbdccbaaaaab_`
M\WPTYXVWW[^_`WZ[[_acbaXcbcccdXP\b\fkidc[SRRRRQQPPNRTV]aba`abbhbceecWUWZ_aeeeecccccbbbaaa``
MXROTRSYYU[`_^[Y[[Z]aabVbcdbccYR[a\fkicdZ\RRSPRQPPPPORUZ_b`aaiibddded]SUY\adeccdccbabbabaa`
JSOOS]UVXZ[`__][Z[\[\_cccccccdYQ\_]fkidcZURUSPQQPPQPOOQTW]`beljbdaedee`VTW]decddcccbbbacaa`
JOOOS\ZWVY[`_`]Y[[\[][]cbccdccUR\^\gkiccZRSUa[QOPQPQOOOOSUYakmiccadddcdcZTZbfbedccbbcbbbaa`
KOOOU\WY`XZa`^][[[\[\[[]accdccUQ]\^hkicdYTSRQ[aXOOQOQPQOOQT_mmjccddeedcdd`]beddddccbbcbbaaa
JPNPU^SY_Y\c`^ZZ[[\\\W[[\_cdbdUR\Z^ikiccYV`YRPT_`TNOPPPPPOO^mmjcdccegcbbcccbfcddddbbcbcabaa
KOOPU[SZ]X[e__YX\[\\\[ab\\_bcdUR]X^hkjcc[RSXQSPOVa]QNPPPQPP`mmkcd]_ehc_abcbbdddececccbcbbaa
LQPRURR[ZV\__^VV[[\\]^bb][[]abUQ]W_hkiccYSRQSRQQPNZaYOOOQQR_mmjcd]Zefd_^^babacddddcbdbcbbba
KUTUUOSXXV\\_]QV[[\\\_ca_[\]]cYQ_V`hkidcZURRQSRQQPOP]`TPQPS_mmkcdabdgd^___^ab`aeddcccdcbbab
LSUVWPSUPWZW[WPT[[[\]aab`\\\]b[Q^X_ikjccYYZTQRQQPQPPNT_[PQR`mmkdecefddW\^_]`c`acedccccbcbba
MWVVVVWSPW\VRQPT[[[\]bba`]]]]cYQ_X`hkjdcYRU[ZSQQQQOPPPOTQRR^mmkdddde``YV\][^bbabdebddcccbca
LXVYUTWXRV[VRRPTX[]\\bc``]\]^bYR_W`jkjdcYSSQV[XRPPQOPPQOQRR]mhkdeabc\Y\_WW^^\^aceddceccccbb
MWYXWUUVZW[WQQPTZ[[\\fca^\^\^c[R`XaikkcdYSRRRSV\UQPQOPPPRRR^ibhdd^Wb\W]_^^T\YUccedeeddcdccb
NWXUYYWSWYZYQOQV[Z[[^cbb][\]^c\R`WaikjecXSSRRRQRZ[UPOPPQPRR^hchddeae]U]_^a\]\Xcceededdccdbb
M[YWXZYYWYYZUORTY\[[]`bbZY]^^c\YcZakkkddYRRRRRRQPSZZQPQQQRR]idge`bgfd^]^``_a]Ucceeeeeddccbc
LW]YXYYZYYWXXTUTW[[]^^`aXW]]^b\^a`cikkcdYSRQSQRQQPPUZWSOQQR^h^efaY]deeYU^__`b`cceeeeeddcdcc
LQT\\YYZZ[[ZVX[ZZ[YY]\\]SX\]_b\_a_bjkkddXSRRRRQRRPQOOV[UQQS]j_ifefa]aed_XY____bcfeefdedddcU
M[QSW]ZZYXZ[ZWXZ[[YU^[UTRV]]^a[^`^ckkjdeXSRSQRQRQQPQPQPURQR]mmmfdfgf_]beb\X[^TacefefedeedSS
OWQWRT]]ZZ[Z[Z[WXZ\[\[URRW\]_`Y^a^cjkjddWTSQSRRQQQQPPQQPRQS]mfkecfefgb\\de^Ya\cdfffeeefcQVT
MUQ[\TSX^\[[ZZ\YVW[\]\TRRW]^__[]`^ckljedWSSSRQRRQQPQPQPQQRR\icggefe_dee`]adbb]cdfeffefcQYSP
NVR[_`[SU]^[[\[\\ZV\]^UQRX]^`^[^`^cklkdeXSRSRSQRRPQQPQQPQSS[jegffhheffdfd\]ac`cdfffffcPWWPO
NWR[__b^XSX^^[[\[\[]Y^XRSZ\]a_Y]`^dkljedWSSSSQRRQQPQPQQQQQS\jdggefghifa_dd`\^bccgegfeUSTVRP
NWRY`_aa`\UU\^^\Y]\]]ZZYW[]]a^[^_]dklkedXSSSRRRRQQQPQPQRQRR[jZagfhhhgefcfded^Z_cfggffYZbUTN
NVRY__a`Q^`YSX_^\]]]\]]\\\\]a][^_ZdlljfdWSSSRSQRRQPQPQQPRRR[mekge^cgbdehfd`ccb]bgfgffeffbQK
NURV_`a]P]ba^WU\`^\][Z\]\\]^a\\]`ZclljeeWTSSRRRRQQPQPQQQQRS[mmmhfa^g`^fhedcebcecgfggfffeeVd
MUQT[aa[QW]`^`[UW__][ZV]]]]^`][^^YdlljedVTSSQRSQQQQQPQQQRRSZmfihefff[[ed`dffba^bgfggffeedXN
NXRSYaaYR[^ZYbb`YT[`^]ZZ\^]^b\Z^^XdmlkeeVTSSRSQRRQQPQQQQRQSZkefhehhg\Zd`\cgecb]bghggfffef`S
MZQRX_aZR[aZW]a^_]SW^`][]^^^cZ[_]XcmmieeWRTSRQQQQQRQQQQPSRR[ldfhffcgeae_Vbd`a___fhgggffeefX
O[QQV^`[RY_[U_\R[c`ZU\`_]^^^cZ[^\ZclmifeX[TSTTSOOQPQRQQQRSRZldfiefghheeaWbaZ_[TafhhgfgffeeT
N\RRU]_ZSU_[\`aSYcdb_XW__^^^bYZ^[XdllkeeWXRYZ]caZQOOQQQQSRRZlX^ieZ[ggfee`baV]c`bghgggfffedO
NXURU\^[ST[YV^aSYcdccWZT\``^cYZ^[XdlmjefVTSZ]XX`ec_RNPQQSRRZmiljed`efgefecdW]b_cfhggggffebO
MX[SV]_ZSTZVSZ_UYccd`O`_WW_adYY_ZXdmljeeVYaZ[SRPQYcd\ROPRRSZmmmjegffcfffeddb_a\cfhgggfffecO
NVRXZ]_]RSYWSW^TYbcf]Q`eb]U\_X[][YdmmjfeWUZWQRRSRQPZdbZRQRSZmggjeeegdeffddedaa`bghhggggfedO
O^^^]^_^VS[WSVZUVaddZPZb[__WTW[]ZXdmmifeX][RQPRRQRRPS[dbTQTWmeejeecf^bec_dfeb]TafhhgggffddQ
O^^^^^`][Y^XSUZTT]db^Q__S\db]V[^XYelmiffUTY]^TOPRQQSQQT\TRSXmfejedfg]_fedde_bc]bfhhgghfffdQ
O^^^^`_\^Z\]RU[USYdb_T_cU[decW[\YXfmmiffUSRRX^]UQPQQSRQQRRTWmfdje^Xfhef^Zcf_bcccehhghfgfedS
N_^^^_`^XZ]^[Y]TSXca_T^bU[eebY[[YZemmjieUSSSRRV]^UPPRRPSRRSWm\\jegbdhgfd\de`bcTbeihhgfgffdS
M]^_^``__ZY]\[`TRXbb]UX_W[decXZ[XZfmmifdTSRSRSQQW]^UOQRQRRSWmikkefhdaefffdbSacW`ehhghgffeeS
LQY]`_`````XY^^[TYbb]TV\W\decW[ZX[fmmjfdUSRSSQRSQRU^]VOQQRSXlmmkegfffgfefee`bc^`fhhhhggfeeU
MQOT[^a``_`b^W[^W]bb]TU[UXceaY[YY\emmigaUSSRQSSQRSQPV]]VRSSVmhgkefehiie``beeccS^fhhhggfgee[
LPRORW]``a`b`a[U[`bb]QTZVU`eaX[YZ\glmid]USSSSQSQSRRRRQU[SSSVmfdkedfgjifffdefddbcdihhggfgeed
LOPQQPRZ^`abaaaabbbb_XUZVT]d`X\W\]fmmiaWRSRSSSRRRRRRQSRRRQTVmfdkeaVfjhehhed`ccccehhhhgfffd]
MQPQQQPRS]`babbbbbca^^\]TT[d_W[Y[]gmmieaRORSSSRTQSRQSRRRRSSWlgclegdghhfghfeaaedcdighhggffe]
NSUQQQQRPRV^abbbbbcc\^^_ZS\c_WZX\\fmmiffeYNNQSSSSSRRSRQRRSTVl`Zkeghheidfheeaa`_cdihghgfgef_
MTUVSRORQRQRZ`bbcccca[\`^X^c]WYX^^fmmifikkh[MOQTQSTSRSSRRTSVlgflefhgeeafgedU^b]`dihhhgggff]
MUTVTUSPPRQQQT]bccbddc_[ZZ`c]V[X_]gmligkkhilh]OLQRSRTSSRRSSUlmmlddag`Z]cdecbab`echighggff`M
MUUTTVUVRQPQRQQX_ccddccc^bcd\VYY\]fmmhillfeljjh_PLOSRSTRRSSUlmmled_e`V]c^_bcddfecihhhggfeON
LTUTUUVVUUQPQRQQS[`dddcdcccd\VZXZ]fmliklkgdjeflljaRMOSSSSRTUllklebcedV]b]UbddddebihhggfgTNR
MUUVUUUVUUVSRPQQQRU\cedcdcdd[WYYY^fmlkmllfdjfejgglkcVMNQSSSVkfclebVcgaccYSbdddd^aihighf^MPS
MSTVTWUUUUUXUTQQQQQRX_cddcdd[UZYW]hmlklllc`kgcjfdkhjkeXMORTVkf\ldgadggdf]Wa\X[_V`jjhhfgOXVR
MUTTUVUUVUUVVVVSPRQRQSZadeceZVYZW^gmlllmljckfcjgckeekjkg\QORle`legjfhfcefb^WXWUS\[`ZhhYVfVR
MTUTUUUVUVTWVWUVVSPPQSQU^bedZTZYX]gmlkkhlmlke]kfcjfdjdflki_Tjb^lehmigd__e_XSPPTWVTOShdRfeWQ
MTUTVTUVVUVUWUUWUWTSPQRSSX`cXTZYW^hmkli[cikkkkmd_kfdjeeieikjmieleijicb``\ZTU]^TUQPRU_T]ffVR
LTSUUVTVUUVVVVVWWUVVURPRRRTXUUYYV^gmklg^[ekkkkkkflcakecidghekmmlfhmiba_^[VR^d`XPTTUTTRPegXR
LRTTUVTVWVWWVVVXWVVWWUTRQSSSVTZZ\cgmllhggjllklkkklhbkdcjdehcimmlfe]bab`]_R[__YSSd_[SONT\\VQ
LOPRTTUUWUVWUXVVYVWVWWVVTSQTVUY^aagmklgijmklkkkkkkkkkdbjcegdhlmlega``b__YP^^\VOVa\URRhgQQRQ
LOOOQSTUVUWVWXVWVVVWWWVVWVTSVU[__`gmkkhikmklclklkkkkjkkladhchjmmegcb`b_]TS^[\RXWZYQPagZQLNP
LNPNPOTSTVUUWVVWVVWWVVWVWVWVWU]_^`hllkghjmkk[lkkmlklkjjkjji^gjmlfgc`a`_VQX^VSQ^V[XPT^XRP^XO
KPNPNPNPSUUUUWVVWWWUWWVXWVWWWW\^_`hmllh^amlk^lllikmmmklkkjjhjklmffb_a]VSQ[]RQT^VTVWYUTNSgXO
LOOOOOOOOQSTUUVVVWWXWVVWWWWVWXZ\]_ikklkigmklglkl[Xaafkljkkjjjkklefgc_YWRTZWRPV^URRYX\UV[eXO
MNPNPNPOOOORTTUUUWWWXWVWWVWXWWYXZ]hgijlllmklmjlkYMOQQY_eklkkkjjjdf\_\YWRWVTQP\YRPRZXSVc[eYO
MOOOOOOOOOOOQRTTUVVVWWWXVWXWXXWXYZ^adfiiljlkkkllf\PPRRT\_fkehkjjfhY_XYVQVRTPRYSRPXYSPVe\eZO
LOOOOOOOOPPPOOQRUVUVVWVXXVXXXXZXZYZZ\`dfiiklllkllkiWNPRQPPYUVljkfgZ\XXWSSPTOXTVPR[WQPZf]d[O
LOOOOOOOPOPOPPOOQSUUVVWXXWXYXYXZYYYZZ[\_cfhjkmlkklmd`RNPRRPQUhkkff\ZWVRRQQQPUSUPSVQQRdg[dZP
LOOOOPOPOOPOQPQOPQQSUVVXYWXXXYZXZZZYY[[Z]^behjkmmlk^lk`ONLOOOUkkgf_aYUSSQQPRRQTPSRQQUff]e]P
LPOOOPOPOPPPPQQPPQPQRTVWXWVYYYYYYZXZ[YY[[Z\^adgjkkmkkkkihaUUOSkkff^\VUTQQPRQQRSQSQQQVeg[f_P
MOOPPOPOQPOQPQPQRQQQQPTTVVVYYZYYYYYX[YY[Z[[Z\]_cghjklmkkklkkjeklgg][WUTPQRSRQPPSQQPQSff\f`P
NOPOPOPPOQOQQQQQQRQQQQQQSUWXYXYXYYYXZZYZ\Y[[ZZXZ]adhhkklkkkkllkkhg[[VURRQTSQPQRRQPQQSffZhaQ
NOOPPPOPQPQPQPRQQRQSRRQRQRSVYYYWYYYX[YZZZZZZ[]`XXY\_bfijjlllkkklhi[XTURQSTQPQSSRQQPQSegZhcQ
MQOPPPPPPPRPPPQQQRRQSSRSRRQSUVZXXXYYY[YY[ZZZY`jf^WXZX]`dfijkllkkhi[WTVQRRSRPSSQORQTTTeg[hbR
OROQPQPPPQRQPQQSQRQRSSRSSSRSQSUVYWYXYZZZ[ZZYZ_kjie\WYZYZ^aegijkmhhcOSURSRSQQRTRPRST[Seg\heQ
OTQPQPQPPQTPQQSQQRSRRSSSTSSTRRQTVWYWZY\YZYZZZ_kkkkhcXWYXYWZ^bfgjfhi\UUSQSTQRRQRPSTZ[Teg\hbR
OSSRPQPQQQURPSQSQRSRRSSSTSSTTSSSRTVXXY[XZZZZZ_kkkkkjgaWVXXYWXZ_caihhZVTQTURRSRRQTS]ZTeh\h]R
ORTSQPRQPRRRRRRRRSRRTSRTSSTSTTTTSSSUVWYXYZZZZ_klkkkkkjg^VXXYYXVXYiiibYUUTVRRRTQRTU\[Udh\i_R
PSTSSRQQQRUQQRRRRSSRRURSTTSTTTSUTVSTTUWWYYY[Y`llkllkkkkif`XYXYYXYhikh^WVVUTRUSRQTT^[Tff]h`T
PTTTTSQRRSURQRRSRSSRSRTSSSSTTSUTUTUTTTUTVXZZYaklllkkkkkkkdZXYXXXW[agid^XVVTUSTRRUT[\Ued^eaT
QSTTTUTQQTUQRQRSSRSSSSRTSSSTSUTUTVTUTUUTSVXZ[alklllkkkkkjdYXXXXXXWWU]aa_[XUUUTTTTV\\Tec`ccT
PSTTTUTSSSTQRSRRRTSSSSSSTSSSTTTUTUUTUUVUUTUVWakkmlljkkkkkdYXXXVYXWXVUUXZ\ZWWVUVTVV[\Ud`aacU
PRVTUUTUSUQSRSQTRSTRSSSTSSSSUSUTTUUTVUVVUUUTU_llllmklllkkeYXYXWXXWVXVVWUUWXXXWWVVWZ\Tc_babV
PSUUUTVUUVRRSRRSSRTSSSSTSSSTSTUUTUTUUUVVUUUVV`lkkllkmkllleXXYWXXWXWXVWVVWVVVWWWYYV\\Ub]c_dU
PTTVUUVUVUSSRRSSTRTSSTSSSTTSSTUTUUVTUUUVUVVVV`lljjlllklklfXXYXXXWXWXWVWXVVVVTTVXYW\\V`\e`bV
QSWTUVVUUVUSSRSSSTSSSSTSSTTTTSUTTUVTVUVUVUWVVblljkmlkjlllfYXXXXXXWXWWXWWVWVVTUTRUW[]Ua\e_cV
PVUUUWTVVUVVTRSTSVSTSSSSTTSUTSUTUTUVUUVVVUWWW`mmmmmlkimmleXXWYXYXXWWWWWWWVVVUVUSTUUVUZZf`dV
PVUWUVVVVWUXURTSTUUSSSTSSTTTUSUTUUTUUUUVWVVVWammmmmllkmmlfVUVWXXWXXWXVXXVVVVUWUTUUUTSWWgadX
PVWVVWWUXUVWVVSTTTUTSTSTTSTTSUTUTUUUUVUUWUWVWammmmmmmmmmlfVTVUUVWXXXWXWVVWVWTVTUUVUVXYXgadY
PTVWVWWWVVXVWVWSOPWTSTTTSTTTTUTUTVTUUUVVUVWVWbmmmmmmmmmmmgVWUVUUUVWWVXVWVVVVVUTUUWUVYYWeaeZ
PTUVXVWVWWWWWWW[`[WTTSTSTTTTUTTUVTUUUUVUWVVVWbmlmmmmmmmllgWWWWWVVUUVUVWVVVVWUWUUUWUVWWYbafZ
PUTTXXWWWWWVWWXWghWTTTTTTTUTSUTVTTVUUUVUUVWVWcllmmmmmmmllgWWXWXWWWUVVUTVVUWVVUVUUWUVYW^^bfZ
PUUTUYYWWWWWWWWWggVTUSUSTTTTVTTUUTUUUUVVTVVVVcmkmmmmmmmmlgWXXWWXXWVWWVUUUUWUUUVUTWVU[Z[\bdZ
QTVTUVXXWVXWWWXXZeWUTTSTUTTTTUUTTVUTVUUVUVWVVcmllmmmlmlmmhWXXWXWWXWWWWVWUVTUUUUUTWVVY\QZbbY
PSVUTUYVWVXVXWXWXXUUSTTUUTTUTTTUTUUUVTWUUVVWWbmllmlmlllmmhXWXXWXXWWWWWWWWWVVVTTUVXUWX^VY`aZ
RVTUUVXWZ]WXXVXWYWWUTTTUTUTUTYVTVUTVUUUVUVVWVcmllllllllklhWXXWWXWXXWWVVWXWWWVWVUVVVUV\]V__Y
T`UUVVUVWYXXWXXXWYXWTUTUTTUTU_UUUUVUTVUUUVWVVcmmmlmkmmljkhXWXWWXXWVXWWVWWWWWVWVWVYUUWY^X]^Z
Sc_WVVUWVXZYXWXXXYWXVUTUTUUUVSUUVTVUUUVUUVVVWdmmmmmmmmlkjhWXXXWXVXXVXVWUXWWWWWVXUYVVWY_Y]^Z
TcaaXUVWVVX[YXXYXXXWXWTUUTVTZVTVUVUUUVVUUVWVWcmmmmmmmmmmlgXXXXWWWXWXVWWUXWWWWWWVWYWUVZb[[^[
TbbcbWVYUVVX[YYWYXXXYXVTUUTWYUVTUUVUUUWTWUVWWcmmmmmmmmmmmiXWXWXXVXWXWVVWWVXVXWWVVYVVVYc\[]Z
TbcbcbV]UVVUY[ZYXWYXXYXVSRQXUUUUXVUUUVUVVVVWWdmmmmmmmmmmmiXWXWWXVXXWXVVWWWWWXWVWWXVWVXcYZ]Z
TcbcdbX]VVVVVZZZXXYXXXXXXi]WVUWYXUUUVUUVVVVVXdmmmmmmmmmmmiXWXXVXWWWXVWVVYWXVXWWVWYVWUZa\\[[
TccccdY\VVUWVVY[YXYXXYXY\geQRUXVUVUUUVVUVVUXVdmmmmmmmmmmmiWXWXXWWXWWWWVU\XWWXWWVVZVWV[]^[\Z
TbbccbZ]UTUUWUV\\XXXYXXYZaa__VUVUVUUUVUUVVVVXdmmmmmmmmmmmiYXWWXVXWXVXVVU_WWWXVWXVXWWWZZa][[
Uaa`bcZ\``UUVVVX\YXXYXXYZckmcaUUVUUUVUWYUVUWXdmmmmmmmmmmmiWXXXVXWWWWWVVU_XWWXWWWWXXWYXXaZ[[
Ubaabc\[bgaSUVWWW]]\YYXYZdkla_WVTVVTVWZUVVVVWdmmmmmmmmmmmiYXWWVWXVWWVWVT_VWXVWXWV[WVYYVg^\[
U^dcac\YdggbTVVVWZZ[ZZWYYemk`]WUUVUUVXUUVVVWVdmmmmmmmmmmmiYVXXWVWWWWVVWU[VXVXWVXWXXWYXWd]\[
RZ_cbb^XdffgcVUVWWVY[ZXYYfmk_\WTUVUUUWUUVVUWVfmmmmmmmmmmljXWWWXVWVXVWVVVZVWXWUXWVXVVZXX_\\Z
RYX\ca^XefgfgeVVWVVWZ[ZXYgmk_\WUUUUUWXUVUUVWVfmmmmmmmmmmliXWVXWWWWVWVVWUXWVWVWWWWYWWZVW]`\[
QWXW[\^WeeffhgdXYZVVWY[[Yhmk^[XWUTUXWUVUVUUWVfmmmmmmmmmmljWWWWWWVVWVVVWUWVWWVXWVVZ[WYW[Xd\[
QVXWVU_Weegfgghf\WWVWVZ[Zhmm_[WXV\YWUUVVUVUVVfmmmmmmmmmmljVWXWUXVWVWVVWUWVVWWVVWVZ\XXVZWe^[
RVUWWX_Weeffgggg^WVVWVXZ[]^aX]UXY_^UVUUVUVUVVgmmmmmmmmlmljWWXVVWWVVVWVVUVVVWVWWVWY\YYU[Wd_\
RUVWVW_Xeffggghg`WTUVWWW\]b`VZVWYYYUVTUVUUVVUhmmmmmmmmmlljWVWVWVWVWVVVVVVVVWVWWVWWWZWU\Zc_^
QUVUVW]Y^fffghhg``dTVVWY[[baUXVWX[WVUVUUUUUVVhmmmmmmmlllljWVWWUWWVVWUWUUWWVVWVVWWXV\VT^\^b^
QTVVVV]UX]fghgggacicVVWXXY__VYUWYYXWUWTVVUVUVhmmmmmmllllljVWWVVVVVWVVVVUWWUVWVWVWXUYUU_[Ze^
RUTUVW\WVX^egfff`ehheXUWXX\`TZVVXYXXWXUVUVVVUimmmmmmllllliWWVXUVVVVWUVUVVVVVVWVWUY_YVT`\We_
RTTUVVZWVVZ^fgfeaegiif[TXZ]^V[TVXXYXXZWVVTWVVimmmmmlmlllkiVWVWVVVVVVUVVUVWUVVWVUWX_YVT^\[e_
QUUTUWWWWWX\\cgeaegihig\X\^_TZWWXXXXYYXWWVXVV^glmmmllllkkiWVWUWVVVUVWVUUUVVUVVVVUW_XWT]]Y_a
RUUUVUWWXVY\[\ccafhhhhihZ\^^V[Y]WXXYYYXXZ]XUWWY\cjlmmlkkkiVWWUVVVVWUVUVUVUVVUUVVUVaVVUZ\[[c
RUVUUVVUWXX[\\ZWafihghih\]^_VZWYXXXYXYXXY\ZUUXWYWY_ekmmlkiVWUVWUWVUVVVVUUVVTVVUUVVbUVTYW\`d
RUUVUVVVVWWZ\]ZXagihhhhh\_a]V[UWYXYXYXYYXZWVVVWWXWYXZbhlkiVWUXUVWUVVUVUVUVUUVTUVVVbTUTZ[Zce
RVUVUVVVVWWY\\[Yacihihhg\aa^VZWVWYYYYXXZXYXVWUVXWWYWYWY[dgWVWVVVVUWUVUWUUVUUUUUUVUZTTVZdZ\d
RWWUUWVVVWVWZ\ZY`Zciiihh\dc^V[VVWWY[YYXZXYYXVVVVWWWWXYXXWXWVWUWVVWUVVUUVUTVUTUUTXW[TY[Y[XY`
RYXWWUVVWVWWVZWY`XX`hiii[ed_V\VWVVX[[WXYYYYYXVVVVWXWWWXXXWVVWVVVVVUVUVUUUUVVTUUUYVY\[UV\ZW[
RVXXYUVWVWVWXWWY`YXY`hii[fh`X[UVVVX[\]ZXZYZYYXVWVWWWVXWWWXVVWWVVVVVVUUUUUUVVUTUWWV_XU]YYa]Y
SVUYZVUUVXVWWWXX]YYYY]fj[hkaX]ZVTWXY[_^YYZZYZXXVWVXVWWWWXVWVVVWVVVUVVUUUUUVWTVUWWWdV^_ZXec[
SVVXX[ZXVXWVWWXX[XYY\X[b[kl`Y]_eVVWXYYZ[ZYZZYYXVWWVVWWWVXWVVVWVVUVVUUVUVUVUWTVUXWXaW^[Y\ggb
SVVVVXZ[XVWWWWWYWXYZYZ[Y\lmaX]^eeXUZ\[[[Z[Y[YXYXWVWVWWWVWVWVWVUVWUVVUVUVVUVVVTVXXZ\XZZXaggg
SVVWVVWXYXVXXVXXXYXXZY[\\mmcY]^_if^[c[[Z[[YZYYYXWWWWVWWVWVWVVWUVVVUVVUWVUVVWUVVXWZXVWWX_hgg
SVVVVWVVYYYWWXWXXYXXZZZ[]mmcY]]bkih]a[ZYY\\[YYYYXWWVWVWVWVVWUVVVUVUUVVWUVVWWVUXUYZ_YWXY`fgg
U^YVV[XWVXYZXWXXXXXZYZZ]^mmeZ]\gkkb`aV\YX]^YXZYZXWWVWWWVWVVVUVUVVVVVUVVVVVVWVVXVXYcYXZY_ggh
Vbb[W^VVWWWYYYXWYXXYYZZ]]mmcZ\]ekjcaa^ZXXZWVXYYZWXXWVVVWVVVUWUWUUVVVVUVVVVVWVVYU[Y`YXYZ^ggg
Vcc`W^VWVWVWZZYXXXXYZY[\`mme[\_ejfabahf]XWWUXXXYYXXWWVWUWUWVUVWUVVVVVVWVVVVWVXVVYXaYXZY]ifg
VbcaW\WWVWWWXXZ\\XXYYY[\`mmc[]]hjfdbbgkj]UWVVWXYXYWWXWVWVVVVWUWVUVVVUWUWVUWVWXVUZV_YXYY]ggg
VbbaXZXVWWWWXYZ\a[XXY[Z\cmme[\Y_kjhbbijjgZWVVVVXYVXXXWWVWVVWUVVVUWVUVWVVUWVVWXUVZW^ZXXZ]hgg
W`b_X[UUWWWXWXXYX\YXYY[]cmmc[\XZhljbaijhjcVUWVVYVYWXXWWWVVVVVVVVVVVVVVUWVUVVWXWUZV]\WYZ[hff
Uab_XY^]XWWVXXXWXYYYZY[\`lmc[\WZ[gk`chieieVVVWW\WXWXXWXWVVVVWVVVVVUVWUVVVVVVXXVV[V\]XYZYigf
Vaa^YZfed`[WVWW[WXYZYZZ\^jmc[\WY[Z\ZciififTVWVW\XWWWXXWVVWUVWVVVUVVUVWUVVVVWWXVWZV[^XYZXggf
Uac]Y\dcfgdc^XW_XWYXZ\Z[\jma]ZXY[ZZYchljieVVVVW]YWVXXWWVVWVVVVWUVVVVUWVVVVVVXYWWZWZ]YXYZggf
Vab[Z\dbecefedY_WYXXYZ\]bmma\YYWZZZZa^ijidVVVWW^XZVWWXVWVVVWUVWVUWVUVVVVWUVWXYUWZWY]YYZXggf
Vcc[Z]bcedefff[_WXYXYX\]bmma]ZWXYYZZ`[\djeUWVWV]ZYZYYVVWVVWUVVWUVWVUVVVUWVVXWaYWYWZaYZYXfhe